@@ -73,7 +73,8 @@ class Decanter(Daemon):
 
     def run(self):
         log = None if self.config.test else 'default'
-        server = pywsgi.WSGIServer((self.hostname, self.port), self.app, log=log)
+        server = pywsgi.WSGIServer((
+            self.hostname, self.port), self.app, log=log)
         server.serve_forever()
 
     def runserver(self):
@@ -84,9 +85,8 @@ class Decanter(Daemon):
             {2}
             Welcome to Decanter!
             You're ready to go!
-            Server running on port {0}
-            Check out http://{1}:{0}
-            {2}""".format(self.port, self.hostname, '='*50)))
+            Server running on http://{1}:{0}
+            {2}""".format(self.port, self.hostname, '=' * 50)))
         self.run()
 
     def status(self):
@@ -94,7 +94,8 @@ class Decanter(Daemon):
             with open(self.pidfile, 'r') as fp:
                 pid = int(fp.read())
             os.kill(pid, 0)
-            print("Decanter is running, pidfile: {0}, process: {1}".format(self.pidfile, pid))
+            print("Decanter is running, pidfile: {0}, process: {1}".format(
+                self.pidfile, pid))
         except (OSError, IOError):
             print("Decanter is not running")
 
